@@ -8,14 +8,14 @@ A basic wrapper cibere.dev
 """
 
 __description__ = "A basic wrapper cibere.dev"
-__version__ = "0.4.2"
+__version__ = "0.5.2"
 
 from typing import Literal, NamedTuple
 
-from .client import Client
+from .client import *
 from .errors import *
-from .file import File
-from .searching import SearchResult
+from .file import *
+from .searching import *
 
 
 class VersionInfo(NamedTuple):
